/*
* Copyright (c) 2007-2017 TeamSpeak Systems
*/

#if defined(_MSC_VER) && !defined(_CRT_SECURE_NO_WARNINGS)
#define _CRT_SECURE_NO_WARNINGS
#endif

#ifdef _WIN32
#define WIN32_LEAN_AND_MEAN
#include <Windows.h>
#else
#include <time.h>
#endif
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <teamspeak/public_errors.h>

#include "common.h"

#define CHECK_ERROR_FATAL(x) check_error_ok(x, __FILE__ ,__LINE__, true)
#define CHECK_ERROR(x) check_error_ok(x, __FILE__ ,__LINE__, false)

bool check_error_ok(unsigned int error, const char *file, unsigned int line, bool do_exit)
{
    if (error != ERROR_ok && error != ERROR_ok_no_update)
    {
        printf("Error (%d) occurred on line %d in %s\n", error, line, file);
        if (do_exit)
        {
            printf("Press Enter to terminate\n");
            getchar();
            exit(1);
        }

        return false;
    }
    return true;
}

/*A function so suspend the current thread for a specified amount of milliseconds*/
void sleep_ms(int milliseconds)
{
#ifdef _WIN32
    Sleep(milliseconds);
#else
    struct timespec ts;
    ts.tv_sec = milliseconds / 1000;
    ts.tv_nsec = (milliseconds % 1000) * 1000000;
    nanosleep(&ts, NULL);
#endif
}

/*Return program path ending in path separator, or an empty string if there is
none*/
char* program_path(const char* program_invocation)
{
    char* end;
#ifdef _WIN32
    char pathsep = '\\';
#else
    char pathsep = '/';
#endif
    static char result[4096]; /*note that this entire array is zeroed*/

    if (program_invocation == NULL)
        program_invocation = "";

    end = strrchr(program_invocation, pathsep);
    if (end)
    {
        const int count = (int)(end + 1 - program_invocation);
        strncpy(result, program_invocation, count);
        result[count] = '\0';
    }
    else
        result[0] = '\0';

    return result;
}

void emptyInputBuffer()
{
    int c;
    while ((c = getchar()) != '\n' && c != EOF);
}
